pub struct State {
pub transitions: [u32; 128],
pub composition: Box<[Transformation]>,
}Expand description
A DFA state representing a unique syllable composition.
Each state stores transitions to next states based on ASCII keys and the corresponding transformation stack (composition).
Fields
transitions: [u32; 128]State transition table for 128 ASCII characters. A value of 0 indicates no transition or fallback to the Rule Engine.
composition: Box<[Transformation]>The transformation stack that makes up this state.