pub struct InputMethod {
pub name: String,
pub rules: Vec<Rule>,
pub super_keys: Vec<char>,
pub tone_keys: Vec<char>,
pub appending_keys: Vec<char>,
pub keys: Vec<char>,
}Expand description
A collection of rules defining how keys transform text.
Use the provided static methods (e.g., InputMethod::telex()) to get
standard Vietnamese input methods.
Fields
name: StringThe name of the input method.
rules: Vec<Rule>The complete list of transformation rules.
super_keys: Vec<char>Keys that can affect multiple vowels at once (e.g., ‘w’ in Telex).
tone_keys: Vec<char>Keys that apply tone marks.
appending_keys: Vec<char>Keys that primarily append characters.
keys: Vec<char>All keys that have at least one rule associated with them.
Implementations
Sourceimpl InputMethod
impl InputMethod
Sourcepub fn microsoft_layout() -> Self
pub fn microsoft_layout() -> Self
Microsoft Standard Vietnamese keyboard layout.
Sourcepub fn telex_vni_viqr() -> Self
pub fn telex_vni_viqr() -> Self
Combined Telex, VNI, and VIQR.
Sourcepub fn vni_french_layout() -> Self
pub fn vni_french_layout() -> Self
VNI for French keyboard layouts.