pub struct TransformationStack { /* private fields */ }Expand description
A stack-allocated buffer for transformations to avoid heap allocations in the hot path.
This structure uses a fixed-size array and is extremely fast for frequent updates.
Implementations
Sourceimpl TransformationStack
impl TransformationStack
Sourcepub fn push(&mut self, t: Transformation)
pub fn push(&mut self, t: Transformation)
Pushes a new transformation onto the stack. Does nothing if the stack is full.
Sourcepub fn pop(&mut self) -> Option<Transformation>
pub fn pop(&mut self) -> Option<Transformation>
Removes and returns the last transformation from the stack.
Sourcepub fn as_slice(&self) -> &[Transformation]
pub fn as_slice(&self) -> &[Transformation]
Returns a slice containing all transformations in the stack.
Sourcepub fn as_mut_slice(&mut self) -> &mut [Transformation]
pub fn as_mut_slice(&mut self) -> &mut [Transformation]
Returns a mutable slice containing all transformations in the stack.
Sourcepub fn extend_from_slice(&mut self, other: &[Transformation])
pub fn extend_from_slice(&mut self, other: &[Transformation])
Appends a slice of transformations to the stack.
Sourcepub fn drain_to(&mut self, start: usize, target: &mut TransformationStack)
pub fn drain_to(&mut self, start: usize, target: &mut TransformationStack)
Drains transformations from a starting index into another stack.